#ifndef COMPASSPRIVATE_H
#define COMPASSPRIVATE_H

namespace
{
    static const int HeadingMarker[3][2] = {
        {-2, -1},
        {+2, -1},
        {+0, +1}
    };

    static const int BearingMarker[4][2] = {
        {-1,  0},
        { 0,  1},
        { 1,  0},
        { 0, -1}
    };

    static const char *CompassPoints[8] = {
        "N", "NE", "E", "SE", "S", "SW", "W", "NW"
    };
}

#endif // COMPASSPRIVATE_H
